[slime-cvs] CVS slime/contrib
CVS User trittweiler
trittweiler at common-lisp.net
Tue Dec 29 19:41:05 UTC 2009
Update of /project/slime/cvsroot/slime/contrib
In directory cl-net:/tmp/cvs-serv10049/contrib
Modified Files:
slime-autodoc.el ChangeLog
Log Message:
* slime-autodoc.el (slime-compute-autodoc): Revert last change.
We must return nil to decline.
--- /project/slime/cvsroot/slime/contrib/ChangeLog 2009/12/29 19:29:31 1.322
+++ /project/slime/cvsroot/slime/contrib/ChangeLog 2009/12/29 19:41:05 1.323
@@ -1,5 +1,10 @@
2009-12-29 Tobias C. Rittweiler <tcr at freebits.de>
+ * slime-autodoc.el (slime-compute-autodoc): Revert last change.
+ We must return nil to decline.
+
+2009-12-29 Tobias C. Rittweiler <tcr at freebits.de>
+
More cleanup.
The RP swank:arglist-for-echo-area is now called swank:autodoc.
More information about the slime-cvs
mailing list
--- /project/slime/cvsroot/slime/contrib/slime-autodoc.el 2009/12/29 19:29:31 1.27
+++ /project/slime/cvsroot/slime/contrib/slime-autodoc.el 2009/12/29 19:41:05 1.28
@@ -168,17 +168,19 @@
(let ((cached (slime-get-cached-autodoc cache-key)))
(if cached
cached
- ;; If nothing is in the cache, we first decline, and fetch
- ;; the arglist information asynchronously.
- (slime-eval-async retrieve-form
- (lexical-let ((cache-key cache-key))
- (lambda (doc)
- (unless (eq doc :not-available)
- (setq doc (slime-format-autodoc doc))
- ;; Now that we've got our information,
- ;; get it to the user ASAP.
- (eldoc-message doc)
- (slime-store-into-autodoc-cache cache-key doc))))))))))))
+ ;; If nothing is in the cache, we first decline (by
+ ;; returning nil), and fetch the arglist information
+ ;; asynchronously.
+ (prog1 nil
+ (slime-eval-async retrieve-form
+ (lexical-let ((cache-key cache-key))
+ (lambda (doc)
+ (unless (eq doc :not-available)
+ (setq doc (slime-format-autodoc doc))
+ ;; Now that we've got our information,
+ ;; get it to the user ASAP.
+ (eldoc-message doc)
+ (slime-store-into-autodoc-cache cache-key doc)))))))))))))
(make-variable-buffer-local (defvar slime-autodoc-mode nil))